@@ -1,6 +1,6 @@
 package Math::PariBuild;
 
-$VERSION = '2.030526';
+$VERSION = '2.030527';
 
 require Exporter;
 @ISA = 'Exporter';
@@ -592,7 +592,7 @@ sub patches_for ($) {
 			      'patches/diff_2.1.6_align_power_of_2',
 			      'patches/diff_2.1.7_restart'],
 		 '2.3.*' =>  [
-			($^O =~ /^MSWin32\b/ ? 'patches/diff_2.3.5_mingw-w64' : ()),
+			($^O =~ /^MSWin32\b/ ? ('patches/diff_2.3.5_mingw-w64', 'patches/diff_2.3.5_win_mkdir') : ()),
 			      'patches/diff_2.3.5_stderr_clobber',
 			      'patches/diff-2.3.5-buffer-overflow'],
 		 '2.5.0' =>  [@p250 = qw(patches/diff-2.5.0-x-prototype
@@ -613,6 +613,8 @@ sub patches_for ($) {
 		 '2.12.*' =>  ['patches/diff-2.11.0-all'],		# Untested from here
 		 '2.13.*' =>  ['patches/diff-2.13.3-all'],
 		 '2.14.*' =>  ['patches/diff-2.13.3-all'],
+		 '2.15.*' =>  ['patches/diff-2.13.3-all'],	# untested
+		 '2.16.*' =>  ['patches/diff-2.13.3-all'],	# untested
 		);
   print "Looking for patches for $v...\n";
   my $vv = $v;
